@@ -246,7 +246,7 @@ def main(args):
         direct_open_names = set(direct_open_names).__contains__
 
     if direct_open_exes := args.direct_open_exes:
-        direct_open_exes = set(direct_open_names).__contains__
+        direct_open_exes = set(direct_open_exes).__contains__
 
     from os.path import exists, abspath
 
@@ -367,11 +367,11 @@ parser.add_argument(
     - re      正则表达式模块
 """)
 parser.add_argument(
-    "-dn", "--direct-open-names", nargs="*", default=[], metavar="name", 
+    "-dn", "--direct-open-names", nargs="+", metavar="name", 
     help="为这些名字（忽略大小写）的程序直接打开链接", 
 )
 parser.add_argument(
-    "-de", "--direct-open-exes", nargs="*", default=[], metavar="exec", 
+    "-de", "--direct-open-exes", nargs="+", metavar="exec", 
     help="为这些路径的程序直接打开链接", 
 )
 parser.add_argument("-c", "--make-cache", help="""\
